# Koyash: A Static Website Generator

This is a Python app to create your own static websites.

Koyash is inspired by Jekyll. My whole career consists of times where I've found WEB incredibly fascinating yet almost each time I try to get into a framework I find myself lost in the syntax and the rules. Koyash provides a very easy to use static website generation framework to everyone.

## The Basic Structure

There is one main component in Koyash **A Page**. \
Manually crafting HTML pages is bothersome and rarely practiced nowadays. Instead of killing the creative process by making someone try to center a _div_ for hours, Koyash provides a basic config system for your pages, so you can just select a **Layout**, do some customization and add your content.
